"geoRglmdefunct" <-
  function()
  {
    cat("\n")
    cat("The following functions are no longer used in geoRglm:")
    cat("---------------------------------------------------")
    cat(" pois.log.krige: use pois.krige instead")
    cat(" y50: use p50 instead")
    cat("\n")
  }
    
